@@ -1,26 +1,3 @@
-#' Utilities for managing file names.
-#'
-#' \code{filename} provides a S3 class to represent file names, which is 
-#' inter-convertible with \code{character}.
-#'
-#' Either construct a \code{filename} object with the \code{\link{filename}}
-#' constructor or convert an existing file name from \code{character} to
-#' \code{filename} using \code{\link{as.filename}}.
-#' Then, manage the tags and extensions of the \code{filename} object with
-#' \code{\link{insert}}.
-#'
-#' The functions \code{\link{set_fpath}}, \code{\link{set_fext}}, 
-#' \code{\link{set_fdate}}, and \code{\link{set_ftime}} can be used
-#' on both \code{character} or \code{filename} to modify file names.
-#'
-#' Use \code{\link{tag}} to quickly add or replace a tag on a file name (as a
-#' \code{character} or \code{filename} and coerce into a \code{character}.
-#'
-#' @docType package
-#' @name filename
-#' @importFrom methods is
-NULL
-
 #' Create a filename.
 #'
 #' This function creates a \code{filename} object with a file path, tags, 
@@ -42,7 +19,7 @@ NULL
 #' platforms and are thus omitted; hyphens are omitted from date-time stamps
 #' for brevity.
 #'
-#' By default, a date stamped subdirectory is appended to the filepath.
+#' By default, a date stamped subdirectory is appended to the file path.
 #' To disable this behaviour, set \code{subdir} to \code{FALSE} or disable
 #' path stamping globally by \code{options(filenamer.path.timestamp = 0)}.
 #' This option is similar to \code{filenamer.timestamp} above.
